=====
Usage
=====

- basic example in the `package README <https://github.com/Quantmetry/pipeasy-spark/>`_.
- basic demo (notebook): `how to pre-process a pyspark dataframe <https://github.com/Quantmetry/pipeasy-spark/blob/master/notebooks/basic_demo.ipynb />`_.
- advanced (notebook): `use a preprocessing pipeline for maching learning <https://github.com/Quantmetry/pipeasy-spark/blob/master/notebooks/titanic-pySpark.ipynb/>`_.
